<?php
/**
 *	{$project_id}_Filter_ExecutionTime.php
 *
 *	@author		{$author}
 *	@package	{$project_id}
 *	@version	$Id: app.filter.default.php,v 1.5 2006/06/05 15:54:32 fujimoto Exp $
 */

/**
 *	¹Իַ¬ե륿μ
 *
 *	@author		{$author}
 *	@access		public
 *	@package	{$project_id}
 */
class {$project_id}_Filter_ExecutionTime extends Ethna_Filter
{
	/**#@+
	 *	@access	private
	 */

	/**
	 *	@var	int		ϻ
	 */
	var	$stime;

	/**#@-*/


	/**
	 *	¹ե륿
	 *
	 *	@access	public
	 */
	function preFilter()
	{
		$stime = explode(' ', microtime());
		$stime = $stime[1] + $stime[0];
		$this->stime = $stime;
	}

	/**
	 *	¹ե륿
	 *
	 *	@access	public
	 *	@param	string	$action_name	¹Ԥ륢̾
	 *	@return	string	null:ｪλ (string):¹Ԥ륢̾ѹ
	 */
	function preActionFilter($action_name)
	{
		return null;
	}

	/**
	 *	¹Ըե륿
	 *
	 *	@access	public
	 *	@param	string	$action_name	¹Ԥ줿̾
	 *	@param	string	$forward_name	¹Ԥ줿󤫤
	 *	@return	string	null:ｪλ (string):̾ѹ
	 */
	function postActionFilter($action_name, $forward_name)
	{
		return null;
	}

	/**
	 *	¹Ըե륿
	 *
	 *	@access	public
	 */
	function postFilter()
	{
		$etime = explode(' ', microtime());
		$etime = $etime[1] + $etime[0];
		$time   = round(($etime - $this->stime), 4);

		print "\n<!-- page was processed in $time seconds -->\n";
	}
}
?>
